.. 2018-05-12 sonofeft 7e7f531cb2af0e8e11f9c257af1326871d62b1b1
   Maintain spacing of "History" and "GitHub Log" titles

History
=======

GitHub Log
----------

* June 19, 2020
    - (by: sonofeft) 
        - Fixed some units issues and some unit test issues

* Jul 1, 2018
    - (by: sonofeft) 
        - Fixed python 3.x error

 
* Jun 30, 2018
    - (by: sonofeft) 
        - handle missing Visc, Cond and NBP
        - detect missing visc, cond and NBP

* May 12, 2018
    - (by: sonofeft) 
        - added python 3.5 to travis.yml
    - (by: Charlie Taylor) 
        - use README.txt instead
    - (by: sonofeft) 
        - First Commit of Project
    - (by: Charlie Taylor) 
        - Initial commit

* May 10, 2018
    - (by: sonofeft)
        - First Created EngCoolProp with PyHatch
